yakumo.neutron.v2.lb.health_monitor

Package yakumo :: Package neutron :: Package v2 :: Package lb :: Module health_monitor |
[hide private]
[frames] | no frames]

# Module health_monitor

source code

Resource class and its manager for LB Health Monitors in Networking V2 API

Classes | [hide private]
| Resource Resource class for LB Health Monitors in Networking V2 API
| Manager Manager class for LB Health Monitors in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2.lb``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('project', 'tenant_id', mapper.Resource('
      project')), ('is_enabled', 'admin_state_up', mapper.Noop), ('pools', '
      pools', mapper.List(mapper.Resource('neutron.lb.pool'))), ('type', 'ty
      pe', mapper.Noop), ('http_method', 'http_method', mapper.Noop), ('url_
      path', 'url_path', mapper.Noop), ('expected_codes', 'expected_codes',
      mapper.Noop), ('delay', 'delay', mapper.Noop), ('timeout', 'timeout',
      mapper.Noop), ('max_retries', 'max_retries', mapper.Noop),]